@@ -32,12 +32,13 @@
 
 #include <X11/Xlib.h>
 
+#include <stdarg.h>
+
 #define XFDESKTOP_CHANNEL        "xfce4-desktop"
-#define DEFAULT_BACKDROP         DATADIR "/backgrounds/xfce/xfce-blue.jpg"
+#define DEFAULT_BACKDROP         DATADIR "/backgrounds/xfce/xfce-teal.jpg"
 #define DEFAULT_ICON_FONT_SIZE   12
 #define DEFAULT_ICON_SIZE        48
-#define ITHEME_FLAGS             (GTK_ICON_LOOKUP_USE_BUILTIN \
-                                  | GTK_ICON_LOOKUP_GENERIC_FALLBACK)
+#define ITHEME_FLAGS             (GTK_ICON_LOOKUP_USE_BUILTIN)
 
 #define LIST_TEXT                "# xfce backdrop list"
 #define XFDESKTOP_SELECTION_FMT  "XFDESKTOP_SELECTION_%d"
@@ -54,6 +55,7 @@
 #define SINGLE_WORKSPACE_NUMBER   "/backdrop/single-workspace-number"
 
 #define DESKTOP_ICONS_SHOW_THUMBNAILS        "/desktop-icons/show-thumbnails"
+#define DESKTOP_ICONS_SHOW_HIDDEN_FILES      "/desktop-icons/show-hidden-files"
 #define DESKTOP_ICONS_SHOW_NETWORK_REMOVABLE "/desktop-icons/file-icons/show-network-removable"
 #define DESKTOP_ICONS_SHOW_DEVICE_REMOVABLE  "/desktop-icons/file-icons/show-device-removable"
 #define DESKTOP_ICONS_SHOW_UNKNWON_REMOVABLE "/desktop-icons/file-icons/show-unknown-removable"
@@ -87,13 +89,38 @@
 
 G_BEGIN_DECLS
 
+gchar* xfdesktop_get_monitor_name_from_gtk_widget(GtkWidget *widget,
+                                                  gint monitor_num);
+
+gint xfdesktop_compare_paths(GFile *a, GFile *b);
+
 gboolean xfdesktop_image_file_is_valid(const gchar *filename);
 
 gchar *xfdesktop_get_file_mimetype(const gchar *file);
 
 gint xfce_translate_image_styles(gint input);
 
-guint32 xfdesktop_popup_keyboard_grab_available(GdkWindow *win);
+gchar* xfdesktop_remove_whitspaces(gchar* str);
+
+GtkWidget* xfdesktop_menu_create_menu_item_with_markup(const gchar *name,
+                                                       GtkWidget   *image);
+
+GtkWidget* xfdesktop_menu_create_menu_item_with_mnemonic(const gchar *name,
+                                                         GtkWidget   *image);
+
+#if defined(G_HAVE_ISO_VARARGS)
+
+#define XF_DEBUG(...) xfdesktop_debug (__func__, __FILE__, __LINE__, __VA_ARGS__)
+
+void xfdesktop_debug(const char *func, const char *file, int line, const char *format, ...) __attribute__((format (printf,4,5)));
+
+#else /* defined(G_HAVE_ISO_VARARGS) */
+
+#define XF_DEBUG(...)
+
+#endif /* defined(G_HAVE_ISO_VARARGS) */
+
+void xfdesktop_debug_set(gboolean debug);
 
 G_END_DECLS
 
